pub struct Update {
pub no_pull: bool,
pub keep: bool,
}Expand description
Update all dependencies of the reproducible environment
Fields
no_pull: boolDo not attempt to pull the container tag from registry before resolving it
keep: boolDo not delete the build container, wait for ctrl-c