pub struct PackageLock {
pub name: String,
pub version: String,
pub system: String,
pub url: String,
pub provides: Vec<String>,
pub sha256: String,
pub signature: Option<String>,
pub installed: bool,
}Fields
name: Stringversion: Stringsystem: Stringurl: Stringprovides: Vec<String>sha256: Stringsignature: Option<String>installed: boolIf true, this package is already present in the container and does not need to be installed. It’s only in the lockfile to make the repro-env.lock diff easier to read and help git’s delta-compression.